#map {
  width: 100%;
  height: 300px; }

html, body {
  height: 100%;
  margin: 0;
  padding: 0; }

.controls {
  margin-top: 10px;
  border: 1px solid transparent;
  border-radius: 2px 0 0 2px;
  box-sizing: border-box;
  -moz-box-sizing: border-box;
  height: 32px;
  outline: none;
  box-shadow: 0 2px 6px rgba(0, 0, 0, 0.3); }

#map-input {
  background-color: #fff;
  font-family: Roboto;
  font-size: 15px;
  font-weight: 300;
  margin-left: 12px;
  padding: 0 11px 0 13px;
  text-overflow: ellipsis;
  width: 300px; }

#map-input:focus {
  border-color: #4d90fe; }

.map-container {
  font-family: Roboto; }

#type-selector {
  color: #fff;
  background-color: #4d90fe;
  padding: 5px 11px 0px 11px; }

#type-selector label {
  font-family: Roboto;
  font-size: 13px;
  font-weight: 300; }

#target {
  width: 345px; }

/*# sourceMappingURL=custom.css.map */
