<input id="map-input" class="controls" type="text" placeholder="Search Box">
<div id="map" {% if latitude %} data-latitude="{{latitude}}" {% endif %} {% if longitude %} data-longitude="{{longitude}}" {% endif %}></div>
